@@ -20,8 +20,9 @@ ProviderWindow::ProviderWindow(QWidget *parent, WrPlugin *plugin) :
     ui->tblProviders->setModel(model);
     ui->tblProviders->setProperty("FingerScrollable", true);
     ui->tblProviders->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+    editMode = false;
     refreshProviders();
-    setAttribute(Qt::WA_Maemo5StackedWindow);
+//    setAttribute(Qt::WA_Maemo5StackedWindow);
 }
 
 ProviderWindow::~ProviderWindow()
@@ -39,17 +40,19 @@ void ProviderWindow::refreshProviders() {
         itemData.insert("baseUri", provider->baseUri);
         itemData.insert("providerId", i);
 
-        QStandardItem *providerItem = new QStandardItem(provider->name);
-        QStandardItem *editItem = new QStandardItem("Edit");
-        QStandardItem *removeItem = new QStandardItem("Remove");
-
+        QStandardItem *providerItem = new QStandardItem(provider->name + "<br/><span style='font-size: small; color: grey'>" +
+                                                        provider->baseUri.replace("%s", plugin->barcodeText) + "</span>");
         providerItem->setData(itemData);
-        editItem->setData(itemData);
-        removeItem->setData(itemData);
-
         model->setItem(row, 0, providerItem);
-        model->setItem(row, 1, editItem);
-        model->setItem(row, 2, removeItem);
+
+        if(editMode) {
+            QStandardItem *editItem = new QStandardItem("Edit");
+            QStandardItem *removeItem = new QStandardItem("Remove");
+            editItem->setData(itemData);
+            removeItem->setData(itemData);
+            model->setItem(row, 1, editItem);
+            model->setItem(row, 2, removeItem);
+        }
         row++;
     }
     qDebug() << "Providers added";
@@ -76,24 +79,28 @@ void ProviderWindow::on_tblProviders_clicked(QModelIndex index)
     int providerId = itemData.value("providerId").toInt();
     qDebug() << "Checking column";
     if(item->column() == 0) {
-        QString uri = baseUri.replace("%s", QUrl::toPercentEncoding(plugin->barcodeText)); // replace %s with barcodeText
-        QDBusInterface *interface = new QDBusInterface("com.nokia.osso_browser","/com/nokia/osso_browser/request","com.nokia.osso_browser");
-        interface->call("open_new_window",uri);
-    } else if(item->column() == 1) {
+        if(!editMode) {
+            QString uri = baseUri.replace("%s", QUrl::toPercentEncoding(plugin->barcodeText)); // replace %s with barcodeText
+            QDBusInterface *interface = new QDBusInterface("com.nokia.osso_browser","/com/nokia/osso_browser/request","com.nokia.osso_browser");
+            interface->call("open_new_window",uri);
+        }
+    } else if(item->column() == 1 && editMode) {
         EditProviderDialog *dialog = new EditProviderDialog(this, plugin->searchProviders().at(providerId));
         if(dialog->exec() == QDialog::Accepted) {
             QList<SearchProvider*> providers = plugin->searchProviders();
             providers.at(providerId)->baseUri = dialog->providerAddress();
             providers.at(providerId)->name = dialog->providerName();
             plugin->setSearchProviders(providers);
+            refreshProviders();
         }
-    } else if(item->column() == 2) {
+    } else if(item->column() == 2 && editMode) {
         QMessageBox *prompt = new QMessageBox(this);
         prompt->setWindowTitle("Remove search provider?");
         prompt->setText("Are you sure you want to remove this search provider?");
         prompt->setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
         if(prompt->exec() == QMessageBox::Ok) {
             plugin->removeSearchProvider(plugin->searchProviders().at(providerId));
+            refreshProviders();
         }
     }
     qDebug() << "done click";
@@ -107,3 +114,13 @@ void ProviderWindow::on_actionAdd_Custom_Search_triggered()
         plugin->addSearchProvider(new SearchProvider(dialog->providerName(), dialog->providerAddress()));
     }
 }
+
+void ProviderWindow::on_actionEdit_mode_triggered()
+{
+    editMode = !editMode;
+    if(editMode) {
+        ui->actionEdit_mode->setText("Disable Edit Mode");
+    } else {
+        ui->actionEdit_mode->setText("Enable Edit Mode");
+    }
+}
