@@ -24,8 +24,10 @@ private:
     Ui::ProviderWindow *ui;
     WrPlugin *plugin;
     QStandardItemModel *model;
+    bool editMode;
 
 private slots:
+    void on_actionEdit_mode_triggered();
     void on_actionAdd_Custom_Search_triggered();
     void on_tblProviders_clicked(QModelIndex index);
 };
